resolve_send_signer

Function resolve_send_signer 

async fn resolve_send_signer(
    pre_resolved: Option<WalletSigner>,
    eth: &EthereumOpts,
) -> Result<(WalletSigner, Address)>
Resolves the sending signer, falling back to the wallet options, and validates it against an explicit --from.