pub(crate) async fn send_tip20_transaction(
to: Address,
data: Vec<u8>,
send_tx: SendTxOpts,
tx: TxParams,
) -> Result<()>Expand description
Sends pre-encoded data to the Tempo contract at to through the cast send flow, signing
with the selected Tempo session, access key, or wallet.